Registers the sequential foreach backend after a parallel cluster has been stopped, so later
parallel foreach calls do not try to use the closed cluster.
Registers the sequential foreach backend after a parallel cluster has been stopped, so later
parallel foreach calls do not try to use the closed cluster.