Relate Deconvolution Subgroups to PROGENy Pathways
Source:R/cell_deconvolution.R
compute_subgroups_pathways.RdComputes PROGENy pathway activity from normalized counts and evaluates module relationships between subgroup profiles and pathway activity profiles.
Usage
compute_subgroups_pathways(
subgroups,
counts_norm,
file_name = "Test",
height = 6,
width = 12,
par_mar = c(4, 25, 5, 3),
pval = 0.05
)Arguments
- subgroups
Output list from
compute.deconvolution.analysis().- counts_norm
Normalized expression matrix with genes in rows and samples in columns.
- file_name
Prefix used to save output files.
- height
Plot height in inches.
- width
Plot width in inches.
- par_mar
Numeric vector passed to plot margins.
- pval
P-value threshold used in module relationship plots.