Creates Results/ (or Results/<subdir>) in the working directory if it does not exist yet.
Every function that saves files calls this right before writing.
Creates Results/ (or Results/<subdir>) in the working directory if it does not exist yet.
Every function that saves files calls this right before writing.